@@ -28,6 +28,7 @@ enum iSourceFormat {
     undefined_SourceFormat = -1,
     gemini_SourceFormat    = 0,
     plainText_SourceFormat,
+    markdown_SourceFormat,
 };
 
 enum iFileVersion {
@@ -125,11 +126,13 @@ iLocalDef int acceptKeyMod_ReturnKeyBehavior(int behavior) {
 #define delete_Icon         "\u232b"
 #define copy_Icon           "\u2398" //"\u2bba"
 #define check_Icon          "\u2714"
-#define ballotCheck_Icon    "\U0001f5f9"
+#define ballotChecked_Icon  "\u2611"
+#define ballotUnchecked_Icon "\u2610"
 #define inbox_Icon          "\U0001f4e5"
 #define book_Icon           "\U0001f56e"
 #define bookmark_Icon       "\U0001f516"
 #define folder_Icon         "\U0001f4c1"
+#define file_Icon           "\U0001f5ce"
 #define openTab_Icon        "\u2750"
 #define openTabBg_Icon      "\u2b1a"
 #define openExt_Icon        "\u27a0"
@@ -159,6 +162,7 @@ iLocalDef int acceptKeyMod_ReturnKeyBehavior(int behavior) {
 #define select_Icon         "\u2b1a"
 #define downAngle_Icon      "\ufe40"
 #define photo_Icon          "\U0001f5bc"
+#define fontpack_Icon       "\U0001f520"
 
 #if defined (iPlatformApple)
 #   define shift_Icon       "\u21e7"
