@@ -76,11 +76,11 @@ static const iMenuItem navMenuItems_[] = {
     { "${menu.feeds.entrylist}", 0, 0, "!open url:about:feeds" },
     { "---" },
     { gear_Icon " ${menu.preferences}", SDLK_COMMA, KMOD_PRIMARY, "preferences" },
-    { "${menu.help}", SDLK_F1, 0, "!open url:about:help" },
-    { "${menu.releasenotes}", 0, 0, "!open url:about:version" },
  #if defined (LAGRANGE_ENABLE_WINSPARKLE)
     { "${menu.update}", 0, 0, "updater.check" },
  #endif
+    { "${menu.help}", SDLK_F1, 0, "!open url:about:help" },
+    { "${menu.releasenotes}", 0, 0, "!open url:about:version" },
     { "---" },
     { "${menu.quit}", 'q', KMOD_PRIMARY, "quit" }
 };
@@ -1317,7 +1317,8 @@ void createUserInterface_Root(iRoot *d) {
             setBackgroundColor_Widget(buttons, uiBackground_ColorId);
         }
         setId_Widget(
-            addChild_Widget(buttons, iClob(newIcon_LabelWidget(add_Icon, 0, 0, "tabs.new"))),
+            addChildFlags_Widget(buttons, iClob(newIcon_LabelWidget(add_Icon, 0, 0, "tabs.new")),
+                                 moveToParentRightEdge_WidgetFlag),
             "newtab");
     }
     /* Sidebars. */ {
